package com.sun.jmx.remote.security;

import java.security.Permissions;
import java.security.cert.Certificate;
import java.security.AccessController;
import java.security.AccessControlContext;
import javax.security.auth.Subject;
import java.security.ProtectionDomain;
import java.security.CodeSource;
import javax.security.auth.SubjectDomainCombiner;

public class JMXSubjectDomainCombiner extends SubjectDomainCombiner
{
    private static final CodeSource nullCodeSource;
    private static final ProtectionDomain pdNoPerms;
    
    public JMXSubjectDomainCombiner(Subject subject) {
        super(subject);
    }
    
    @Override
    public ProtectionDomain[] combine(ProtectionDomain[] array, ProtectionDomain[] assignedDomains) {
        ProtectionDomain[] currentDomains;
        if (array == null || array.length == 0) {
            currentDomains = new ProtectionDomain[] { JMXSubjectDomainCombiner.pdNoPerms };
        }
        else {
            currentDomains = new ProtectionDomain[array.length + 1];
            for (int i = 0; i < array.length; ++i) {
                currentDomains[i] = array[i];
            }
            currentDomains[array.length] = JMXSubjectDomainCombiner.pdNoPerms;
        }
        return super.combine(currentDomains, assignedDomains);
    }
    
    public static AccessControlContext getContext(Subject subject) {
        return new AccessControlContext(AccessController.getContext(), new JMXSubjectDomainCombiner(subject));
    }
    
    public static AccessControlContext getDomainCombinerContext(Subject subject) {
        return new AccessControlContext(new AccessControlContext(new ProtectionDomain[0]), new JMXSubjectDomainCombiner(subject));
    }
    
    static {
        nullCodeSource = new CodeSource(null, (Certificate[])null);
        pdNoPerms = new ProtectionDomain(JMXSubjectDomainCombiner.nullCodeSource, new Permissions(), null, null);
    }
}
